==> huaweicloudsdkmrs-3.1.112-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/show_mrs_version_list_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMrsVersionListResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_versions': 'list[str]'
    }

    attribute_map = {
        'cluster_versions': 'cluster_versions'
    }

    def __init__(self, cluster_versions=None):
        """ShowMrsVersionListResponse

        The model defined in huaweicloud sdk

        :param cluster_versions: 可用集群版本列表
        :type cluster_versions: list[str]
        """
        
        super(ShowMrsVersionListResponse, self).__init__()

        self._cluster_versions = None
        self.discriminator = None

        if cluster_versions is not None:
            self.cluster_versions = cluster_versions

    @property
    def cluster_versions(self):
        """Gets the cluster_versions of this ShowMrsVersionListResponse.

        可用集群版本列表

        :return: The cluster_versions of this ShowMrsVersionListResponse.
        :rtype: list[str]
        """
        return self._cluster_versions

    @cluster_versions.setter
    def cluster_versions(self, cluster_versions):
        """Sets the cluster_versions of this ShowMrsVersionListResponse.

        可用集群版本列表

        :param cluster_versions: The cluster_versions of this ShowMrsVersionListResponse.
        :type cluster_versions: list[str]
        """
        self._cluster_versions = cluster_versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMrsVersionListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.1.155-py2.py3-none-any.whl: huaweicloudsdkmrs/v2/model/show_mrs_version_list_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMrsVersionListResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_versions': 'list[str]'
    }

    attribute_map = {
        'cluster_versions': 'cluster_versions'
    }

    def __init__(self, cluster_versions=None):
        r"""ShowMrsVersionListResponse

        The model defined in huaweicloud sdk

        :param cluster_versions: 可用集群版本列表
        :type cluster_versions: list[str]
        """
        
        super(ShowMrsVersionListResponse, self).__init__()

        self._cluster_versions = None
        self.discriminator = None

        if cluster_versions is not None:
            self.cluster_versions = cluster_versions

    @property
    def cluster_versions(self):
        r"""Gets the cluster_versions of this ShowMrsVersionListResponse.

        可用集群版本列表

        :return: The cluster_versions of this ShowMrsVersionListResponse.
        :rtype: list[str]
        """
        return self._cluster_versions

    @cluster_versions.setter
    def cluster_versions(self, cluster_versions):
        r"""Sets the cluster_versions of this ShowMrsVersionListResponse.

        可用集群版本列表

        :param cluster_versions: The cluster_versions of this ShowMrsVersionListResponse.
        :type cluster_versions: list[str]
        """
        self._cluster_versions = cluster_versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMrsVersionListResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
